# Handle the incoming configuration files:
config() {
  for infile in $1; do
    NEW="$infile"
    OLD="$(dirname $NEW)/$(basename $NEW .new)"
    # If there's no config file by that name, mv it over:
    if [ ! -r $OLD ]; then
      mv $NEW $OLD
    elif [ "$(cat $OLD | md5sum)" = "$(cat $NEW | md5sum)" ]; then
      # toss the redundant copy
      rm $NEW
    fi
    # Otherwise, we leave the .new copy for the admin to consider...
  done
}

preserve_perms() {
  NEW="$1"
  OLD="$(dirname $NEW)/$(basename $NEW .new)"
  if [ -e $OLD ]; then
    cp -a $OLD ${NEW}.incoming
    cat $NEW > ${NEW}.incoming
    mv ${NEW}.incoming $NEW
  fi
  config $NEW
}

config etc/mongod.conf.new
preserve_perms etc/rc.d/rc.mongodb.new

# Only way to create and use the correct uid and gid on the target system,
# is to use chroot:
chroot . <<EOR 2>/dev/null
# Add the '285' group if it doesn't exist already:
/usr/sbin/groupadd -g 285 mongo 2> /dev/null

# Add the '285' user if it doesn't exist already:
/usr/sbin/useradd -c "MongoDB server account" -d /var/lib/mongodb -M \
  -s "/bin/false" -g 285 -u 285 mongo 2> /dev/null
EOR

# Update rc.local so that MongoDB will be started on boot
if ! grep "rc.mongodb" etc/rc.d/rc.local 1>/dev/null 2>&1 ; then
  cat <<_EOM_ >> etc/rc.d/rc.local

if [ -x /etc/rc.d/rc.mongodb ]; then
  # Start MongoDB server
  echo "Starting MongoDB:    /etc/rc.d/rc.mongodb start"
  /etc/rc.d/rc.mongodb start
fi
_EOM_
fi

( cd usr/lib64/mongodb ; rm -rf libstdc++.so.6 )
( cd usr/lib64/mongodb ; ln -sf libstdc++.so.6.0.27 libstdc++.so.6 )
